@@ -1,5 +1,5 @@
 package Test::Inter;
-# Copyright (c) 2010-2019 Sullivan Beck. All rights reserved.
+# Copyright (c) 2010-2024 Sullivan Beck. All rights reserved.
 # This program is free software; you can redistribute it and/or modify it
 # under the same terms as Perl itself.
 
@@ -11,9 +11,10 @@ use warnings;
 use strict;
 use File::Basename;
 use IO::File;
+use Cwd 'abs_path';
 
 our($VERSION);
-$VERSION = '1.08';
+$VERSION='1.11';
 
 ###############################################################################
 # BASE METHODS
@@ -74,60 +75,61 @@ sub new {
 
    no strict 'refs';
    foreach my $opt (@opts) {
-      if (! exists $o{$opt}) {
-         $self->_die("Invalid option to new method: $opt");
-      }
-
       my $OPT = uc("ti_$opt");
 
-      if (exists $opts{opt}  ||
-          exists $ENV{$OPT}  ||
-          defined ${ "main::$OPT" }) {
-
-         my $val;
-         if (defined ${ "main::$OPT" }) {
-            $val = ${ "main::$OPT" };
-         } elsif (exists $ENV{$OPT}) {
-            $val = $ENV{$OPT};
-         } else {
-            $val = $opts{$opt};
-         }
-
-         &{ "Test::Inter::$opt" }($self,$val);
+      my $val;
+      if (defined ${ "main::$OPT" }) {
+         $val = ${ "main::$OPT" };
+      } elsif (exists $ENV{$OPT}) {
+         $val = $ENV{$OPT};
+      } elsif (exists $opts{$opt}) {
+         $val = $opts{$opt};
+      } else {
+         next;
       }
+
+      &{ "Test::Inter::$opt" }($self,$val);
    }
 
+   # uncoverable branch true
    if ($$self{'mode'} ne 'test') {
-      print "\nRunning $name...\n";
+      print "\nRunning $name...\n";  # uncoverable statement
    }
 
-   # Find the test directory
-   #
-   # Scripts will either be run:
-   #    directly (look at $0)
-   #    as a test suite (look for ./t and ../t)
+   # We assume that the module is distributed in a directory with the correct
+   # hierarchy.  This is:
+   #      /some/path      MODDIR
+   #                /t    TESTDIR
+   #                /lib  LIBDIR
+   # We'll find the full path to each.
 
-   my($TDIR,@LIBDIR);
+   my($moddir,$testdir,$libdir);
+
+   # uncoverable branch false
+   # uncoverable branch true count:2
+   # uncoverable branch false count:2
+   # uncoverable branch true count:3
+   # uncoverable branch false count:3
    if (-f "$0") {
-      my $COM = $0;
-      $TDIR   = dirname($COM);
-      $TDIR   = '.'  if (! $TDIR);
-   } elsif (-d 't') {
-      $TDIR   = 't';
-   } else {
-      $TDIR   = '.';
+      $moddir = dirname(dirname(abs_path($0)));
+   } elsif (-d "./t") {
+      $moddir = dirname(abs_path('.'));   # uncoverable statement
+   } elsif (-d "../t") {
+      $moddir = dirname(abs_path('..'));  # uncoverable statement
    }
 
-   @LIBDIR = ('.');
-   if (-d "$TDIR/lib") {
-      push(@LIBDIR,"$TDIR/lib");
+   # uncoverable branch false
+   if (-d "$moddir/t") {
+      $testdir = "$moddir/t";
    }
-   if (-d "$TDIR/../lib") {
-      push(@LIBDIR,"$TDIR/../lib");
+   # uncoverable branch false
+   if (-d "$moddir/lib") {
+      $libdir  = "$moddir/lib";
    }
 
-   $$self{'testdir'} = $TDIR;
-   $$self{'libdir'}  = \@LIBDIR;
+   $$self{'moddir'}  = $moddir;
+   $$self{'testdir'} = $testdir;
+   $$self{'libdir'}  = $libdir;
 
    $self->use_lib();
 
@@ -142,14 +144,20 @@ sub use_lib {
    }
 
    if ($$self{'use_lib'} eq 'on') {
-      foreach my $dir (@{ $$self{'libdir'} }) {
+      foreach my $dir ($$self{'libdir'},$$self{'testdir'}) {
+         next  if (! defined $dir);
          eval "use lib '$dir'";
       }
    }
 }
 
 sub testdir {
-   my($self) = @_;
+   my($self,$req) = @_;
+   if ($req  &&  $req eq 'mod') {
+      return $$self{'moddir'};
+   } elsif ($req  &&  $req eq 'lib') {
+      return $$self{'libdir'};
+   }
    return $$self{'testdir'};
 }
 
@@ -301,7 +309,8 @@ sub require_ok {
    $main::TI_NUM++  unless ($mode eq 'feature');
 
    my $pack = caller;
-   my @inc  = map { "unshift(\@INC,'$_');\n" } @{ $$self{'libdir'} };
+   my @inc  = map { "unshift(\@INC,'$_');\n" }
+     ($$self{'libdir'},$$self{'testdir'});
 
    my($desc,$code);
 
@@ -315,10 +324,14 @@ REQUIRE
    } else {
       $module = qq['$module'] unless $self->_is_module_name($module);
       $desc   = "require $module";
+      # So the following do not get picked up by cpantorpm-depreq or other
+      # tools that try to determine dependencies and prereqs
+      my $p   = "package";
+      my $r   = "require";
       $code   = <<REQUIRE;
-package $pack;
+$p $pack;
 @inc
-require $module;
+$r $module;
 1;
 REQUIRE
    }
@@ -416,10 +429,13 @@ USE
       my $imports = (@args ? 'qw(' . join(' ',@args) . ')' : '');
       $desc = "use $module $vers $imports";
 
-      my @inc  = map { "unshift(\@INC,'$_');\n" } @{ $$self{'libdir'} };
+      my @inc  = map { "unshift(\@INC,'$_');\n" } ($$self{'libdir'},$$self{'testdir'});
 
+      # So the following do not get picked up by cpantorpm-depreq or other
+      # tools that try to determine dependencies and prereqs
+      my $p   = "package";
       $code = <<USE;
-package $pack;
+$p $pack;
 @inc
 use $module $vers $imports;
 1;
@@ -958,13 +974,15 @@ sub tests {
    if (exists $opts{'feature'}) {
       foreach my $feature (@{ $opts{'feature'} }) {
          $skip = "Required feature unavailable: $feature", last
-           if (! exists $$self{'features'}{$feature});
+           if (! exists $$self{'features'}{$feature}  ||
+               ! $$self{'features'}{$feature});
       }
    }
    if (exists $opts{'disable'}  &&  ! $skip) {
       foreach my $feature (@{ $opts{'disable'} }) {
          $skip = "Disabled due to feature being available: $feature", last
-           if (exists $$self{'features'}{$feature});
+           if (exists $$self{'features'}{$feature}  &&
+               $$self{'features'}{$feature});
       }
    }
 
